@@ -364,19 +364,23 @@ impl POFile {
 
 impl fmt::Display for POFile {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        let mut ret = match self.header {
+        let mut ret: String = match self.header {
             Some(ref header) => {
-                let mut header_repr = String::new();
-                for line in header.lines() {
-                    if line.is_empty() {
-                        header_repr.push_str("#\n");
-                    } else {
-                        header_repr.push_str("# ");
-                        header_repr.push_str(line);
-                        header_repr.push('\n');
+                if header.is_empty() {
+                    "#\n".to_string()
+                } else {
+                    let mut header_repr = String::new();
+                    for line in header.lines() {
+                        if line.is_empty() {
+                            header_repr.push_str("#\n");
+                        } else {
+                            header_repr.push_str("# ");
+                            header_repr.push_str(line);
+                            header_repr.push('\n');
+                        }
                     }
+                    header_repr
                 }
-                header_repr
             }
             None => "#\n".to_string(),
         };
@@ -577,19 +581,6 @@ msgstr \"\"
         );
     }
 
-    #[test]
-    fn mofile_from_pofile() {
-        let path = "tests-data/all.po";
-        let po_file = pofile(path).unwrap();
-        let mo_file = MOFile::from(&po_file);
-
-        assert_eq!(
-            mo_file.entries.len(),
-            po_file.translated_entries().len(),
-        );
-        assert_eq!(mo_file.metadata.len(), po_file.metadata.len());
-    }
-
     #[test]
     fn pofile_percent_translated() {
         let path = "tests-data/2-translated-entries.po";
@@ -877,4 +868,37 @@ msgstr "oof"
             "msgctxt for msgid_plural 1"
         );
     }
+
+    #[test]
+    fn parse_escapes_are_unescaped_on_format() {
+        let path = "tests-data/escapes.po";
+        let file = pofile(path).unwrap();
+
+        let expected_content =
+            "\\ \t \r \u{8} \n \\\n \u{11} \u{12} \\\\";
+
+        assert_eq!(file.entries.len(), 1);
+        assert_eq!(file.entries[0].msgid, expected_content);
+        assert_eq!(
+            file.entries[0].msgstr.as_ref().unwrap(),
+            expected_content,
+        );
+    }
+
+    #[test]
+    fn parse_and_format_escapes() {
+        let path = "tests-data/escapes.po";
+        let out_path = "tests-data/tests/parse_and_format_escapes.po";
+
+        let file = pofile(path).unwrap();
+        file.save(out_path);
+
+        let escapes_content = fs::read_to_string(path).unwrap();
+        let out_content = fs::read_to_string(out_path).unwrap();
+
+        assert_eq!(
+            escapes_content.replace("\r\n", "\n"),
+            out_content
+        );
+    }
 }
